==> igniteui-react-18.7.0-beta.2.tgz: package/esm5/lib/igr-dropdown-item.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrBaseOptionLike } from "./igr-base-option-like";
import { DropdownItem } from "./DropdownItem";
import { IgcDropdownItemComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp } from "igniteui-react-core";
/**
 * Represents an item in a dropdown list.
*/
var IgrDropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDropdownItem, _super);
    function IgrDropdownItem(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcDropdownItemComponent);
        return _this;
    }
    IgrDropdownItem.prototype.createImplementation = function () {
        return new DropdownItem();
    };
    Object.defineProperty(IgrDropdownItem.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItem.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrDropdownItem.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-dropdown-item", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrDropdownItem.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrDropdownItem;
}(IgrBaseOptionLike));
export { IgrDropdownItem };

==> igniteui-react-18.7.5-beta.2.tgz: package/esm5/lib/igr-dropdown-item.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrBaseOptionLike } from "./igr-base-option-like";
import { DropdownItem } from "./DropdownItem";
import { IgcDropdownItemComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp } from "igniteui-react-core";
/**
 * Represents an item in a dropdown list.
*/
var IgrDropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDropdownItem, _super);
    function IgrDropdownItem(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcDropdownItemComponent);
        return _this;
    }
    IgrDropdownItem.prototype.createImplementation = function () {
        return new DropdownItem();
    };
    Object.defineProperty(IgrDropdownItem.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItem.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrDropdownItem.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef" && prop !== "className"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-dropdown-item", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrDropdownItem.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrDropdownItem;
}(IgrBaseOptionLike));
export { IgrDropdownItem };
